@@ -91,8 +91,6 @@ mod bounding_box;
 mod color_rgba8;
 mod float_ext;
 mod iso_transform;
-mod mat3_ext;
-mod mat4_ext;
 #[cfg(not(target_arch = "spirv"))]
 mod mesh_gen;
 mod plane3;
@@ -105,8 +103,8 @@ mod vec3_ext;
 mod vec4_ext;
 
 pub use self::{
-    bounding_box::*, float_ext::*, iso_transform::*, mat3_ext::*, mat4_ext::*, plane3::*, ray3::*,
-    utils::*, vec2_ext::*, vec3_ext::*, vec4_ext::*,
+    bounding_box::*, float_ext::*, iso_transform::*, plane3::*, ray3::*, utils::*, vec2_ext::*,
+    vec3_ext::*, vec4_ext::*,
 };
 
 #[cfg(not(target_arch = "spirv"))]
@@ -119,8 +117,8 @@ pub use quat_ext::*;
 /// Prelude module with extension traits
 pub mod prelude {
     pub use {
-        crate::FloatExt, crate::Mat3Ext, crate::Mat4Ext, crate::Vec2Ext, crate::Vec2Swizzles,
-        crate::Vec3Ext, crate::Vec3Swizzles, crate::Vec4Ext, crate::Vec4Swizzles,
+        crate::FloatExt, crate::Vec2Ext, crate::Vec2Swizzles, crate::Vec3Ext, crate::Vec3Swizzles,
+        crate::Vec4Ext, crate::Vec4Swizzles,
     };
 
     #[cfg(not(target_arch = "spirv"))]
